@@ -5,8 +5,6 @@ import time
 import datetime
 from pandas.core.frame import DataFrame
 
-from ..web3_utils import web3_generic
-from RupineHeroku.rupine_db import herokuCredentials, herokuAbi
 from web3 import Web3
 from collections import deque
 
@@ -134,46 +132,6 @@ def write_to_file(directory:str,filename:str,data:str):
         print(e)
         return False
 
-def get_abi(contract_address:str,chain_id:int):
-    # Deprecated!! Use getABI instead
-    if not Web3.isAddress(contract_address):
-        return None
-    filename = '{0}_{1}.json'.format(str(chain_id),contract_address)
-    abi = read_from_file(os.environ.get('ABI_LOCATION'),filename)
-    if abi != None:
-        return abi
-    else:
-        if chain_id == 1 or chain_id == 3 or chain_id == 4:
-            api_key = os.environ.get('ETH_API_KEY')
-        else:
-            api_key = os.environ.get('BSC_API_KEY')
-        abi = web3_generic.get_contract_abi_by_eth_or_bsc_scan(contract_address,chain_id,api_key)
-        if abi != None:
-            write_to_file(os.environ.get('ABI_LOCATION'),filename,abi)
-        return abi
-
-def getABI(connection, schema, contract_address:str,chain_id:int):
-    if not Web3.isAddress(contract_address):
-        return None
-    #filename = '{0}_{1}.json'.format(str(chain_id),contract_address)
-    
-    result = herokuAbi.getAbi(connection, schema, contract_address, chain_id)
-
-    data = json.loads(result.text)
-    #abi = read_from_file(os.environ.get('ABI_LOCATION'),filename)
-    if len(data) != 0 and 'abi' in data[0]:
-        return data[0]['abi']
-    else:
-        if chain_id in [1,3,4]:
-            api_key = herokuCredentials.getCredential(connection, schema, 'Etherscan','API KEY', 1) 
-        else:
-            api_key = herokuCredentials.getCredential(connection, schema, 'BSCScan','API KEY', 56) 
-        abi = web3_generic.get_contract_abi_by_eth_or_bsc_scan(contract_address,chain_id,api_key)
-        if abi != None:
-            herokuAbi.updateAbi(connection, schema, abi, Web3.toChecksumAddress(contract_address), chain_id)
-            #write_to_file(os.environ.get('ABI_LOCATION'),filename,abi)
-        return abi
-
 def check_ethereum_types_for_value(value,type,output='check'):
     if type == 'uint256':
         if output == 'check': return check_if_int(value) 
