@@ -6,7 +6,7 @@ import urllib.parse as urlparse
 import time
 
 from ..utils import helper
-from ..web3_utils import web3_globals
+from ..web3_utils import web3_globals, web3_generic
 
 def is_list_of_addresses(self,address_list:str):    
     '''
@@ -28,16 +28,16 @@ def is_list_of_addresses(self,address_list:str):
             return False
     return True
 
-def get_lp_pool_of_contract(w3:Web3,chain_id:int,contract_address:str):
-    swap_contract_factory_abi = helper.get_abi(w3.toChecksumAddress(web3_globals.AddrUniSwapV2FactoryAdress),chain_id)
+def get_lp_pool_of_contract(connection, schema, w3:Web3,chain_id:int,contract_address:str):
+    swap_contract_factory_abi = web3_generic.getABI(connection, schema, w3.toChecksumAddress(web3_globals.AddrUniSwapV2FactoryAdress),chain_id)
     swap_contract_factory_instance = w3.eth.contract(address=w3.toChecksumAddress(web3_globals.AddrUniSwapV2FactoryAdress), abi=swap_contract_factory_abi)
     WETH_contract_address = w3.toChecksumAddress(web3_globals.get_address_weth_or_wbnb(chain_id,w3))
     
     lp_contract_address = swap_contract_factory_instance.functions.getPair(WETH_contract_address,w3.toChecksumAddress(contract_address)).call()
     return lp_contract_address
 
-def get_lp_pool_reserves(w3:Web3,chain_id:int,lp_contract_address:str, prodEnv:bool=True, blocknumber='latest'):
-    lp_contract_abi = helper.getABI(w3.toChecksumAddress(lp_contract_address),chain_id,prodEnv)
+def get_lp_pool_reserves(connection, schema, w3:Web3,chain_id:int,lp_contract_address:str, prodEnv:bool=True, blocknumber='latest'):
+    lp_contract_abi = web3_generic.getABI(connection, schema, w3.toChecksumAddress(lp_contract_address),chain_id)
     lp_contract_instance = w3.eth.contract(address=w3.toChecksumAddress(lp_contract_address), abi=lp_contract_abi)
     reserves = lp_contract_instance.functions.getReserves().call(None, blocknumber)
     result = {
@@ -57,9 +57,9 @@ def get_lp_pool_reserves(w3:Web3,chain_id:int,lp_contract_address:str, prodEnv:b
 
     return result
 
-def get_contract_info(w3:Web3,chain_id:int,contract_address:str,function_name:str,abi:str=None,args:list=[],blockNumber=None):
+def get_contract_info(connection, schema, w3:Web3,chain_id:int,contract_address:str,function_name:str,abi:str=None,args:list=[],blockNumber=None):
     if abi == None:
-        contract_abi = helper.get_abi(w3.toChecksumAddress(contract_address),chain_id)
+        contract_abi = web3_generic.getABI(w3.toChecksumAddress(contract_address),chain_id)
     else:
         contract_abi = abi
     contract_instance = w3.eth.contract(address=w3.toChecksumAddress(contract_address), abi=contract_abi)
@@ -150,7 +150,7 @@ def get_token_holder(contract_address:str,covalent_api_key:str,max_working_time_
 #get_token_holder('0x96150e34f8b56b59a53c2caab4510edb3085d070','ckey_5625cf364c744bcb8116949ce76',20)
 
 
-def get_initial_lp_pool_reserves(w3:Web3,chain_id:int,lp_contract_address:str,starting_block:str,ending_block:str):
+def get_initial_lp_pool_reserves(connection, schema, w3:Web3,chain_id:int,lp_contract_address:str,starting_block:str,ending_block:str):
     headers = {
     'Content-Type': 'application/json'
     }
@@ -172,7 +172,7 @@ def get_initial_lp_pool_reserves(w3:Web3,chain_id:int,lp_contract_address:str,st
             reserves[1] = int(r['value'])
     
     result = {}
-    lp_contract_abi = helper.get_abi(w3.toChecksumAddress(lp_contract_address),chain_id)
+    lp_contract_abi = web3_generic.getABI(connection, schema, w3.toChecksumAddress(lp_contract_address),chain_id)
     lp_contract_instance = w3.eth.contract(address=w3.toChecksumAddress(lp_contract_address), abi=lp_contract_abi)
     token0_address = lp_contract_instance.functions.token0().call()
     
